import sqlalchemy as sa
from efa.model.outputindicator import Outputindicator
from formbar.form import Form
from ringo.lib.form import get_form_config



class PWEOutputindicator(Outputindicator):
    """Waskiq specific Outputindicators. Adds some local fields.
    """

    pweparticipation = sa.orm.relation(
        "Participation",
        enable_typechecks=False,
        backref=sa.orm.backref("pweoi",
                               uselist=False,
                               cascade="all"))

    # Status of the outputindicators
    status = sa.Column('status', sa.Integer)

    # Education situation
    edu_attainment_school = sa.Column(
        'edu_attainment_school', sa.Integer)
    edu_attainment_vocational = sa.Column(
        'edu_attainment_vocational', sa.Integer)

    # Labour market situation
    lm_employment_category_employed = sa.Column(
        'lm_employment_category_employed', sa.Integer)
    lm_employment_category_underemployed = sa.Column(
        'lm_employment_category_underemployed', sa.Integer)
    lm_employment_category_selfemployed = sa.Column(
        'lm_employment_category_selfemployed', sa.Integer)
    lm_employment_category_education_enterprise = sa.Column(
        'lm_employment_category_education_enterprise', sa.Integer)
    lm_employment_category_inactive = sa.Column(
        'lm_employment_category_inactive', sa.Integer)
    lm_employment_category_education_school = sa.Column(
        'lm_employment_category_education_school', sa.Integer)
    lm_employment_category_school = sa.Column(
        'lm_employment_category_school', sa.Integer)
    lm_employment_category_fulltime_student = sa.Column(
        'lm_employment_category_fulltime_student', sa.Integer)
    lm_employment_category_training = sa.Column(
        'lm_employment_category_training', sa.Integer)
    lm_employment_category_unemployed = sa.Column(
        'lm_employment_category_unemployed', sa.Integer)
    lm_employment_category_unemployement_duration = sa.Column(
        'lm_employment_category_unemployement_duration', sa.Integer)
    lm_employment_category_unemployment_type = sa.Column(
        'lm_employment_category_unemployment_type', sa.Integer)
    lm_employment_category_lookingforwork = sa.Column(
        'lm_employment_category_lookingforwork', sa.Integer)
    lm_employment_supportpurchased = sa.Column(
        'lm_employment_supportpurchased', sa.Integer)

    # Household situation
    hh_employed = sa.Column('hh_employed', sa.Integer)
    hh_singleparent_depended = sa.Column(
        'hh_singleparent_depended', sa.Integer)

    # Disabilities
    da_resident = sa.Column('da_resident', sa.Integer)

    # General
    misc_german_nationality = sa.Column(
        'misc_german_nationality', sa.Integer)

    # PWE specific fields
    pwe_targetgroup = sa.Column('pwe_targetgroup', sa.Integer)
    pwe_targetgroup_family_phase = sa.Column('pwe_targetgroup_family_phase', sa.Integer)
    pwe_targetgroup_parenttime = sa.Column('pwe_targetgroup_parenttime', sa.Integer)
    pwe_targetgroup_parenttime_specialsupport = sa.Column('pwe_targetgroup_parenttime_specialsupport', sa.Integer)
    pwe_online = sa.Column('pwe_online', sa.Integer)
    pwe_acquisition_pause = sa.Column('pwe_acquisition_pause', sa.Integer)
    pwe_acquisition_pause_reason = sa.Column('pwe_acquisition_pause_reason',
                                             sa.Integer)
    pwe_acquisition_pause_reason_care = sa.Column('pwe_acquisition_pause_reason_care',
                                                  sa.Integer)
    pwe_industry = sa.Column('pwe_industry', sa.String,
                             nullable=False, default='')
    pwe_industry_wish = sa.Column('pwe_industry_wish', sa.String,
                                  nullable=False, default='')
    pwe_labour_time_scope = sa.Column('pwe_labour_time_scope', sa.Integer)
    pwe_labour_interruption = sa.Column('pwe_labour_interruption', sa.Integer)
    pwe_family_phase_minijob = sa.Column('pwe_family_phase_minijob', sa.Integer)
    pwe_hdl_claimed = sa.Column('pwe_hdl_claimed', sa.Integer)
    pwe_hdl_conceivable = sa.Column('pwe_hdl_conceivable', sa.Integer)
    pwe_partner_integrated = sa.Column('pwe_partner_integrated', sa.Integer)
    pwe_partner_integration = sa.Column('pwe_partner_integration', sa.Integer)
       
    lm_employment_category_underemployed_reduced = sa.Column('lm_employment_category_underemployed_reduced', sa.Integer)
    lm_employment_category_selfemployed_reduced = sa.Column('lm_employment_category_selfemployed_reduced', sa.Integer)
    edu_attainment_vocational_experience = sa.Column('edu_attainment_vocational_experience', sa.Integer)
    edu_attainment_vocational_experience2 = sa.Column('edu_attainment_vocational_experience2', sa.Integer)

    # fp 2 fields.
    pwe_targetgroup_fp2 = sa.Column('pwe_targetgroup_fp2', sa.Integer)
    pwe_industry_fp2 = sa.Column('pwe_industry_fp2', sa.Integer)
    pwe_industry_fp2_erzieherin = sa.Column('pwe_industry_fp2_erzieherin',
                                            sa.Integer)
    pwe_industry_fp2_nurse = sa.Column('pwe_industry_fp2_nurse', sa.Integer)
    hh_singleparent_fp2 = sa.Column('hh_singleparent_fp2', sa.Integer)
    hh_employed_fp2 = sa.Column('hh_employed_fp2', sa.Integer)
    pwe_targetgroup_parenttime_fp2 = sa.Column(
        'pwe_targetgroup_parenttime_fp2', sa.Integer)
    pwe_targetgroup_parenttime_specialsupport_fp2 = sa.Column(
        'pwe_targetgroup_parenttime_specialsupport_fp2', sa.Integer)

    def is_complete(self):
        if self.status is not None:
            if self.status == 1:
                return True
            else:
                return False
        form_config = get_form_config(self, "update")
        form = Form(form_config, self)
        form.validate()

        status = not form.has_errors() and not form.has_warnings()
        if status:
            self.status = 1
        else:
            self.status = 0
        return status
